---
title: "Top-Ten"
---
# Top-Ten

Concept, audio, writing: [**Tom Smith**](http://www.thomaswilliamsmith.com/)  
Python scripting, data preparation, copy-editing: **Elizabeth Berry**

{{< soundcloud 1133875915 playlist >}}
[https://soundcloud.com/tmorimoto/sets/top-ten/s-040wawnRobM](https://soundcloud.com/tmorimoto/sets/top-ten/s-040wawnRobM)

## Method

1. Using a python automation script, charts for ten countries with the most Spotify users were compiled from September 2019 to September 2020 (Spotify makes its charts available publicly on a week by week basis). The Top 10 Songs for each region were subsequently 'averaged' over a selection of quantitative and qualitative characteristics to produce a ‘UK song’, a ‘Brazilian song’, a ‘Global’ song, and so on. 

2. The top 10 songs in each country were time-stretched to the mean tempo of songs in the respective country. 

3. Songs were pitch-shifted to C Major and A Minor, which are of the most common keys used in songs on Spotify, as [shown](https://io9.gizmodo.com/a-chart-of-the-most-commonly-used-keys-shows-our-actual-1703086174?IR=T) by Kenny Ning, a former Spotify data engineer. 

4. Songs were then synchronised relative to the prominent opening downbeat (typically where the drum programming begins). 

5. The proportion of streams each song contributed to a country's total streams was used to determine the range of frequencies each song would occupy between 0-22000kHz. For example, Blinding Lights by the Weeknd accounted for 480, 475 991 streams out of the 3, 989 106 975 recorded in the US over that period. Therefore accounting for 12.05% of total US streams and 12.05% of the audible frequencies in the final US song. 

6. The only aspect of the process not determined statistically was selecting where each song would appear in the available frequency range (frequencies between 40 and 5000kHz are the most important musically). Songs were arranged in a manner that attempted to highlight their most salient features, and to achieve a mix that might reflect the overall aesthetic qualities of each country’s chart.

{{< figure src="/images/top-ten/Turkey.png" title="Screenshot showing 'Turkey' duration left to right, frequencies top to bottom. The frequency range and duration of each song can be seen in the horizontal slices." >}}

## Musical and Geographical Reflections

1.	Spotify is most popular in Europe, Latin America, the US and other majority English speaking countries. A comprehensive list is available [here](https://support.spotify.com/us/article/full-list-of-territories-where-spotify-is-available/). 
2.	Majority English speaking countries feature a high proportion of American songs, while charts for majority non-English speaking countries tend to feature mostly local songs. This might appear to contradict US global cultural dominance, however, all of the songs in the global top-ten are American except for one Spanish song and one song in English by a Korean group. Unexpectedly, most of these songs do not appear in the top-ten for any of the individual countries. This perhaps suggests that nation based charts feature a significant portion of local content that is not popular elsewhere, while American content is consumed at high rates globally.  
3. The charts almost exclusively feature music produced with computers and vocalists. Rock is almost entirely absent. Brazil is the major exception: its top ten is dominated by live recordings of Música Sertaneja, an acoustic style originating in Southern Brazil often performed by male sibling duos, featuring conventional instrumentation and strong vibrato. 
4. The tresillo rhythm (sometimes referred to as the 'dem-bow rhythm' after Shabba Ranks’ 1990 song of the same name) originated in sub-Saharan Africa and is often associated with Caribbean genres such as Reggaeton. This rhythm dominates the popular music of Spanish speaking countries. 27 of the 30 top songs from Spain, Mexico and Argentina feature the tresillo rhythm. Although the rhythm now appears extensively in music from beyond the Caribbean and Latin America, this stark rhythmic contrast suggests musical conventions are associated with language groups, with English and Spanish speaking countries forming distinct musical continuums.  
5. The European charts, with the exception of Spain, favour conventional 4/4 rhythms at a higher tempo. 
6. The Indonesian chart features mostly local content, with some songs about specific social issues. For instance the song Halu by Febi Putri recognises the difficulties of living with schizophrenia (stigma towards those with mental illness is common in Indonesia). Some singers also directly address viewers in introductions to their songs on Youtube.  
7.	South Korea is not currently serviced by Spotify even though it has a profitable and influential pop music industry. Spotify’s K-Pop Daebak playlist has over 2.5 million subscribers. Blackpink (a Korean girl-group) appear in the global top ten and hold several streaming records including the most views of a Youtube video in 24 hours. Spotify cite ‘licensing difficulties’ as the reason for their absence in Korea. 
8. The Japanese charts are composed entirely of J-Pop and are the most homogenous, featuring five songs by an artist called Official HIGE DANdism. 
9. Major and Minor keys are used roughly equally among the top ten songs for all countries except Japan and Turkey. Japan’s top ten is almost entirely major, while Turkey's is almost entirely minor.  
10. Despite being the continent from which virtually all modern pop music is in some way derived, Spotify is only available in five African countries: Algeria, Egypt, Morocco, South Africa and Tunisia. South Africa is the only African country Spotify provides chart data for, however the South African user base is too small to provide a useful summary of listening habits, and all top ten songs are by American artists. It may be that in non-western countries where numbers of Spotify users are small, the platform is largely used by ‘expats’, international students, and other members of the globally mobile class.  
11.	These kinds of insights are what Spotify’s data is most useful for. Spotify’s chief ‘data alchemist’ Glenn McDonald (formerly principal engineer at EchoNest, acquired by Spotify in 2014) has provided a series of experiments, such as [everynoise.com](http://everynoise.com/), that present musical data in informative ways.

{{< figure src="/images/top-ten/US-chart.png" title="Screenshot showing data for US top-ten" >}} 

## Spotify, Data and Capital

What role does data collection and analysis actually play in the business plans of prominent startups such as Spotify? Does it make a meaningful contribution to providing a quality product, or is it a cynical hype-building instrument foregrounded for the purposes of attracting investment? 

Spotify was first registered in 2006 by online advertising entrepreneurs Daniel Ek and Martin Lorentzon. Spotify went public in April 2018 valued at over US$29.5 billion, giving Ek and Lorentzon $2.3 billion and $3.1 billion in shares respectively. As is typical for startups, Spotify has relied almost exclusively on injections of cash from private venture capital firms hoping for returns on tech innovation. Spotify continues to attract investors despite being around $2.8 billion in the red. The authors of Spotify Teardown have provided a detailed periodisation of Spotify’s evolution.[^teardown] To summarise, there have been three distinct periods in which Spotify has pursued different business strategies, all of which have attracted enthusiastic investment: 

1. Advertising vs. Subscription: The political and financial issues surrounding illegal file sharing were central to Spotify’s initial business plan (the trial of The Pirate Bay’s founding members took place in Sweden in 2009). Spotify claimed to have found the solution to sustainable online music distribution, offering a free service funded exclusively by advertising, the revenue from which would cover operating costs and pay for licensing/royalty payments to labels and artists.[^royalties]  However, the financial crisis of 2008 precipitated a crash in advertising revenues and Spotify subsequently introduced [subscription](https://www.investopedia.com/articles/investing/120314/spotify-makes-internet-music-make-money.asp) fees, which now make up most of Spotify’s operational income. 

2. Platformisation: After Spotify entered the US for the first time in 2011, it received a large injection of capital from Russian firm DST (Digital Sky Technologies). This investment was associated with a short-lived emphasis on ‘platformisation’, with Spotify attempting to integrate a series of features into Facebook’s interface. Spotify also struck deals with Rolling stone, Pitchfork and The Guardian to embed playlists in music related stories. Ek’s [statement](https://edition.cnn.com/2011/12/08/tech/web/spotify-daniel-ek/index.html) “We believe that music should be like water, it should just exist everywhere” echoes a platformisation approach, which the company pursued by embedding services in existing platforms.

3. Data-driven Personalisation: Before 2013, Spotify provided only simple 'related artist’ recommendations based on genre. Following feedback that the app was difficult to use for listeners, and concern from artists that they would never be heard amongst so much content, Spotify followed Google and Facebook’s lead and began pursuing a strategy based on personalisation. Users would now be shown different content based on their own past activity, and other data provided at sign-up such as gender, age and location. Spotify continued to generate hype among investors who saw personalisation as the way of the future. This shift in strategy accompanied new injections of capital from Goldman Sachs and the Coca-Cola company, and Spotify began acquiring companies that could help it realise its new goal: a fully personalised musical experience.

{{< figure src="/images/top-ten/graph.png" title="Graph shows investor rounds at intervals of 12-18 months, from an initial investment of $22 million up to $1.5 billion in 2016." >}} 

Details on the timing and provenance of Spotify's investor rounds have been made [public](https://www.crunchbase.com/organization/spotify/company_financials). As shown in Figure 2, total investment in the company increased near exponentially as Spotify grew and iteratively adjusted its strategy. Speculative capital’s ongoing faith in the promises of digital technology reveals the cultural meaning of Spotify; it is a placeholder for the mythic value of digital disruption and innovation, functioning as a vessel for investor hopes. The precise locus of these myths shifts as digital systems evolve and new technology emerges, but its contents remain constant: through connection, information, access, convenience, efficiency and optimisation, digital tools will enhance our living and produce new forms of limitless value. 

Data collection, analysis and modeling—advanced versions of which are referred to as ‘Machine Learning’ and ‘AI’—is the current talisman in an ongoing search for high yield tech investments. Bernard Stiegler’s ideas on the pharmacological properties of technology are instructive here. For Stiegler, all technologies contain both poisonous and curative potential. Although new digital technologies do not necessarily function as financial instruments, in our current social milieu "the socialization of digital technologies are accomplished by the poisoning and drive-based side of this pharmakon".[^pharmakon]  Examples set by dot-com forebears such as Amazon, Google, Facebook, eBay and so on, suggest a similar reading.

Enabled by large scale data collection on millions of user profiles, preferences and behaviour, Spotify has developed and honed a Bayesian learning algorithm that processes user information in order to return music suggestions and targeted advertising with the highest predicted probability of a positive interaction (click, like, follow). This algorithmic response is the closest thing Spotify has to a unique product, and is the promise upon which its speculative value relies. Like most companies that trade on mythologies of big data, Spotify is a pyramid scheme, parasitic upon the cultural apparatus it captures. Its data collection and analysis techniques exist primarily to maintain an ongoing speculative bubble, rather than achieve any tangible social or economic value for users and artists.

The ongoing attempt to provide whatever sounds we desire at any given moment, places Spotify in a vanguard position somewhere near the cutting edge of a historical quest to commodify ever more niche areas of human experience, in this case by monetising human desires for the affective lubrication only music can provide. Spotify, and the data inflected myths that prop up its speculative value, are among the latest iterations of an enduring dream that has underpinned subsumption and productive optimisation from the colonial period through to the surveillance capitalism of today; a dream of limitless accumulation unencumbered by the Earthly constraints of labour and materials.  

{{< figure src="/images/top-ten/spot_grab.jpg" title="An advertisement for loans served to me by Spotify" >}} 

Does Spotify enhance musical experience through limitless access? Or does it nullify the scarcity that gives these experiences meaning? Spotify's algorithm serves user suggestions based not only on their own statistics, but what has been popular for users with similar profiles. The result of this is a standardisation and sanitisation of cultural exposure: users' in-app experiences will always be anchored to their own past selves and those adjacent to them, thereby preventing encounters with newness untethered from the world captured by Spotify. Spotify’s product is self-defeating in this respect; it is an algorithmic contradiction creating endless but predictable newness that lapses into a self-same stream.

While the implications of this are far-reaching for the music industry, and culture in general, the effect Spotify has on the worlds it captures does not appear to be of concern to the company. What Spotify means to users and artists as participants in culture is a mere externality to those investing, financing and strategising on behalf of the company. The core concern here is to point out the role new digital technologies play in perpetuating a cycle of investment in disruptive platforms that treat the world they inevitably create as a financial externality. Until there are regulatory frameworks capable of asking more subtle questions and enforcing their findings, the cultural impact of platforms like Spotify will remain entirely determined by the profit motives that produce them.

{{< figure src="/images/top-ten/Global2.png" title="Screenshot showing 'Global' duration left to right; frequencies top to bottom. The frequency range and duration of each song can be seen in the horizontal slices." >}} 

## Afterword

But what of the Top-Ten songs produced during this research? It is my suspicion that the experiential product Spotify wants to sell is a chimera; from the perspective of an individual, streams of new content flatten into sameness at a certain scale. As Steven Shaviro has written, when users are immersed in a feed "everything is always changing, but for that very reason there is absolute monotony, since the mere fact of meaningless change is the only thing there is".[^shaviro]  More and more innovative methods of serving files to users does not produce a seamless experience so much as an intensified version of a culture industry concerned primarily with attracting ears and eyes for the sake of extraction. Perhaps these tracks are an aesthetic index of this reality. Their standardised tempos and timbres, their lack of dynamic and imagination, and the flattening of differences between the songs from which they’re constituted, suggest something of the overall flattening effect Spotify has upon the perception of musical aesthetics. In a listening ecosystem defined by control and optimization, there is no place for surprise. As researcher and artist Samuel Heatley has suggested, "anything can be muzak in contemporary places of service and trade”, in other words, after streaming, all music is ambient music fading into a din where difference collapses and serves to lubricate the flow of capital.[^heatley]  Perhaps by distilling the most common listening habits into a jumble of frequencies and informational detritus, the hollow promise of endless newness can be heard lapsing into a machinic representation of its internal contradictions.  


[^teardown]: Eriksson, Maria, Rasmus Fleischer, Anna Johansson, Pelle Snickars, and Patrick Vonderau. _Spotify teardown: Inside the black box of streaming music_. MIT Press, 2019.

[^royalties]: Royalties and licenses are one of Spotify’s major [expenses](https://www.musicbusinessworldwide.com/loss-making-spotify-will-continue-to-focus-on-growth-over-profit-for-next-few-years/); it has paid an estimated $15 billion in total to labels, publishers, songwriters and artists as of 2020, the majority of which goes to major labels. The [amount](https://soundcharts.com/blog/music-streaming-rates-payouts#streaming-payouts-on-spotify-apple-music-google-play-and-deezer) paid per stream differs by region and artist but the current average is around US$0.0032. So if a song gained 1 million streams, roughly $3200 in revenue would be generated. Some of this would be paid to songwriters as mechanical royalties, while the majority would be paid to the copyright owner of the recording (usually a record label) who would then pay the artist (often 50%, sometimes less). It is not difficult to see why artists are mostly ambivalent about streaming in general. Spotify is only financially viable for Spotify employees, major labels who collect large amounts of royalties in aggregate, and a tiny group of the most popular artists.  

[^pharmakon]: Stiegler, Bernard. _The re-enchantment of the world: the value of spirit against industrial populism_. London: A&C Black, 2014, p21.

[^shaviro]: Shaviro, Steven. Feed. TEXT - Zeitschrift und Verlag., 2016, Retrieved from [http://www.text-revue.net/revue/heft-14/feed/text](http://www.text-revue.net/revue/heft-14/feed/text)

[^heatley]: Sam kindly granted me access to his essay ‘Open for Business’, that will be published in an upcoming edition of [Unlikely](http://unlikely.net.au/) Journal.